@@ -7,7 +7,7 @@
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs to be
 #'   set at the layer level if you are overriding the plot defaults.
-#' @param data A layer specific dataset - only needed if you want to override
+#' @param data A layer specific dataset, only needed if you want to override
 #'   the plot defaults.
 #' @param geom The geometric object to use display the data
 #' @param position The position adjustment to use for overlapping points on this
@@ -24,7 +24,8 @@
 #'   \code{\link[ggplot2]{layer}} for more details.
 #' @param na.rm	a logical indicating whether NA values should be stripped before
 #'   the computation proceeds.
-#' @param formula a formula object.
+#' @param formula a formula object. Using aesthetic names instead of
+#'   original variable names.
 #' @param eq.with.lhs If \code{character} the string is pasted to the front of
 #'   the equation label before parsing or a \code{logical} (see note).
 #' @param eq.x.rhs \code{character} this string will be used as replacement for
@@ -41,7 +42,8 @@
 #'   using npcx and npcy aesthetics.
 #' @param hstep,vstep numeric in npc units, the horizontal and vertical step
 #'   used between labels for different groups.
-#' @param output.type character One of "expression", "LaTeX" or "text".
+#' @param output.type character One of "expression", "LaTeX" or "text",
+#'   or "numeric".
 #'
 #' @note For backward compatibility a logical is accepted as argument for
 #'   \code{eq.with.lhs}, giving the same output than the current default
@@ -59,37 +61,67 @@
 #'   terms, except possibly for the intercept indicated by "- 1" or "-1" in the
 #'   formula. The validity of the \code{formula} is not checked in the current
 #'   implementation, and for this reason the default aesthetics sets R^2 as
-#'   label for the annotation. This stat only generates the label, the predicted
+#'   label for the annotation. This stat only generates labels, the predicted
 #'   values need to be separately added to the plot, so to make sure that the
 #'   same model formula is used in all steps it is best to save the formula as
 #'   an object and supply this object as argument to the different statistics.
 #'
+#'   A ggplot statistic receives as data a data frame that is not the one passed
+#'   as argument by the user, but instead a data frame with the variables mapped
+#'   to aesthetics. stat_poly_eq() mimics how stat_smooth() works, except that
+#'   only polynomials can be fitted. In other words, it respects the grammar of
+#'   graphics. This helps ensure that the model is fitted to the same data as
+#'   plotted in other layers.
+#'
 #' @references Written as an answer to a question at Stackoverflow.
 #'   \url{https://stackoverflow.com/questions/7549694/adding-regression-line-equation-and-r2-on-graph}
 #'
 #'
 #' @section Aesthetics: \code{stat_poly_eq} understands \code{x} and \code{y},
 #'   to be referenced in the \code{formula} and \code{weight} passed as argument
-#'   to parameter \code{weights} of \code{lm()}. All three must be mappeed to
-#'   \code{numeric} variables. In addition the aesthetics undertood by the geom
+#'   to parameter \code{weights} of \code{lm()}. All three must be mapped to
+#'   \code{numeric} variables. In addition, the aesthetics undertood by the geom
 #'   used (\code{"text"} by default) are understood and grouping respected.
 #'
-#' @section Computed variables: \describe{ \item{x}{x position for left edge}
-#'   \item{y}{y position near upper edge} \item{eq.label}{equation for the
-#'   fitted polynomial as a character string to be parsed}
-#'   \item{rr.label}{\eqn{R^2} of the fitted model as a character string to be
-#'   parsed} \item{adj.rr.label}{Adjusted \eqn{R^2} of the fitted model as a
-#'   character string to be parsed} \item{AIC.label}{AIC for the fitted model.}
-#'   \item{BIC.label}{BIC for the fitted model.} \item{hjust}{Set to zero to
-#'   override the default of the "text" geom.}}
+#' @section Computed variables:
+#' If output.type different from \code{"numeric"} the returned tibble contains columns:
+#' \describe{
+#'   \item{x,npcx}{x position}
+#'   \item{y,npcy}{y position}
+#'   \item{coef.ls, r.squared, adj.r.squared, AIC, BIC}{as numric values extracted from fit object}
+#'   \item{eq.label}{equation for the fitted polynomial as a character string to be parsed}
+#'   \item{rr.label}{\eqn{R^2} of the fitted model as a character string to be parsed}
+#'   \item{adj.rr.label}{Adjusted \eqn{R^2} of the fitted model as a character string to be parsed}
+#'   \item{AIC.label}{AIC for the fitted model.}
+#'   \item{BIC.label}{BIC for the fitted model.}
+#'   \item{hjust, vjust}{Set to "inward" to override the default of the "text" geom.}}
 #'
-#' @section Warning!: if using \code{output.type = "expression"}, then
-#'   \code{parse = TRUE} is needed, while if using \code{output.type = "LaTeX"}
-#'   \code{parse = FALSE}, the default of \code{geom_text} and
-#'   \code{geom_label}, should be used.
+#' If output.type is \code{"numeric"} the returned tibble contains columns:
+#' \describe{
+#'   \item{x,npcx}{x position}
+#'   \item{y,npcy}{y position}
+#'   \item{coef.ls}{list containing the "coefficients" matrix from the summary of the fit object}
+#'   \item{r.squared, adj.r.squared, AIC, BIC}{numric values extracted from fit object}
+#'   \item{hjust, vjust}{Set to "inward" to override the default of the "text" geom.}}
+#'
+#' To explore the computed values returned for a given input we sugegst the use
+#' of \code{\link[gginnards]{geom_debug}} as shown in the example below.
+#'
+#' @section Parsing may be required: if using the computed labels with
+#'   \code{output.type = "expression"}, then \code{parse = TRUE} is needed,
+#'   while if using \code{output.type = "LaTeX"} \code{parse = FALSE} is needed.
+#'
+#' @seealso This \code{stat_poly_eq} statistic can return ready formatted labels
+#'   depending on the argument passed to \code{output.type}. This is possible
+#'   because only polynomial models are supported. For other types of models,
+#'   statistics \code{\link{stat_fit_glance}},  \code{\link{stat_fit_tidy}} and
+#'   \code{\link{stat_fit_glance}} should be used instead and the mapping of
+#'   aesthetic \code{label} explicitly supplied in the call.
+#'
+#' @family statistics for linear model fits
 #'
 #' @examples
-#' library(ggplot2)
+#' library(gginnards)
 #' # generate artificial data
 #' set.seed(4321)
 #' x <- 1:100
@@ -98,45 +130,61 @@
 #'                       group = c("A", "B"),
 #'                       y2 = y * c(0.5,2),
 #'                       w = sqrt(x))
+#'
 #' # give a name to a formula
 #' formula <- y ~ poly(x, 3, raw = TRUE)
+#'
 #' # no weights
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(formula = formula, parse = TRUE)
+#'
+#' # as above but using geom_debug()
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   geom_smooth(method = "lm", formula = formula) +
+#'   stat_poly_eq(formula = formula,
+#'                geom = "debug")
+#'
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(formula = formula, parse = TRUE,
 #'                label.y = "bottom", label.x = "right")
+#'
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(formula = formula, parse = TRUE,
 #'                label.y = 0.1, label.x = 0.9)
+#'
 #' # using weights
 #' ggplot(my.data, aes(x, y, weight = w)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(formula = formula, parse = TRUE)
+#'
 #' # no weights, digits for R square
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(formula = formula, rr.digits = 4, parse = TRUE)
+#'
 #' # user specified label
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(aes(label =  paste(stat(eq.label), stat(adj.rr.label), sep = "~~~~")),
 #'                formula = formula, parse = TRUE)
+#'
 #' # user specified label and digits
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   geom_smooth(method = "lm", formula = formula) +
 #'   stat_poly_eq(aes(label =  paste(stat(eq.label), stat(adj.rr.label), sep = "~~~~")),
 #'                formula = formula, rr.digits = 3, coef.digits = 2, parse = TRUE)
+#'
 #' # geom = "text"
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
@@ -144,6 +192,25 @@
 #'   stat_poly_eq(geom = "text", label.x = 100, label.y = 0, hjust = 1,
 #'                formula = formula, parse = TRUE)
 #'
+#' # using numeric values
+#' # Here we use column "Estimate" from the matrix.
+#' # Other available columns are "Std. Error", "t value" and "Pr(>|t|)".
+#' my.format <-
+#'   "b[0]~`=`~%.3g*\", \"*b[1]~`=`~%.3g*\", \"*b[2]~`=`~%.3g*\", \"*b[3]~`=`~%.3g"
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   geom_smooth(method = "lm", formula = formula) +
+#'   stat_poly_eq(formula = formula,
+#'                output.type = "numeric",
+#'                parse = TRUE,
+#'                mapping = aes(label = sprintf(my.format,
+#'                                              stat(coef.ls)[[1]][[1, "Estimate"]],
+#'                                              stat(coef.ls)[[1]][[2, "Estimate"]],
+#'                                              stat(coef.ls)[[1]][[3, "Estimate"]],
+#'                                              stat(coef.ls)[[1]][[4, "Estimate"]])
+#'                                              )
+#'                              )
+#'
 #' @export
 #'
 stat_poly_eq <- function(mapping = NULL, data = NULL,
@@ -254,60 +321,102 @@ poly_eq_compute_group_fun <- function(data,
   lm.args <- list(quote(formula), data = quote(data), weights = quote(weight))
   mf <- do.call(stats::lm, lm.args)
 
-  coefs <- stats::coef(mf)
-  formula.rhs.chr <- as.character(formula)[3]
-  if (grepl("-1", formula.rhs.chr) || grepl("- 1", formula.rhs.chr)) {
-    coefs <- c(0, coefs)
-  }
   rr <- summary(mf)$r.squared
   adj.rr <- summary(mf)$adj.r.squared
   AIC <- AIC(mf)
   BIC <- BIC(mf)
-  eq.char <- as.character(signif(polynom::as.polynomial(coefs), coef.digits))
-  # as character drops 1
-  eq.char <- gsub("+ x", paste("+ 1.", stringr::str_dup("0", coef.digits - 1L),
-                               "*x", sep = ""),
-                  eq.char, fixed = TRUE)
-  eq.char <- gsub("e([+-]?[0-9]*)", "%*%10^{\\1}", eq.char)
-  if (output.type %in% c("latex", "tex", "tikz")) {
-    eq.char <- gsub("*", " ", eq.char, fixed = TRUE)
-  }
-  if (is.character(eq.with.lhs)) {
-    lhs <- eq.with.lhs
-    eq.with.lhs <- TRUE
-  } else if (eq.with.lhs) {
+
+  if (output.type == "numeric") {
+    z <- tibble::tibble(coef.ls = list(summary(mf)[["coefficients"]]),
+                        r.squared = rr,
+                        adj.r.squared = adj.rr,
+                        AIC = AIC,
+                        BIC = BIC)
+  } else {
+    coefs <- stats::coef(mf)
+    formula.rhs.chr <- as.character(formula)[3]
+    if (grepl("-1", formula.rhs.chr) || grepl("- 1", formula.rhs.chr)) {
+      coefs <- c(0, coefs)
+    }
+
+    stopifnot(coef.digits > 0)
+    if (coef.digits < 3) {
+      warning("Rounding coefficient estimates to fewer than three significant digits! Likely information loss!")
+    }
+    eq.char <- as.character(signif(polynom::as.polynomial(coefs), coef.digits))
+    # as character drops 1
+    eq.char <- gsub("+ x", paste("+ 1.", stringr::str_dup("0", coef.digits - 1L),
+                                 "*x", sep = ""),
+                    eq.char, fixed = TRUE)
+    eq.char <- gsub("e([+-]?[0-9]*)", "%*%10^{\\1}", eq.char)
+    if (output.type %in% c("latex", "tex", "tikz")) {
+      eq.char <- gsub("*", " ", eq.char, fixed = TRUE)
+    }
+    if (is.character(eq.with.lhs)) {
+      lhs <- eq.with.lhs
+      eq.with.lhs <- TRUE
+    } else if (eq.with.lhs) {
+      if (output.type == "expression") {
+        lhs <- "italic(y)~`=`~"
+      } else if (output.type %in% c("latex", "tex", "tikz", "text")) {
+        lhs <- "y = "
+      }
+    }
+    if (eq.with.lhs) {
+      eq.char <- paste(lhs, eq.char, sep = "")
+    }
+
+    stopifnot(rr.digits > 0)
+    if (rr.digits < 2) {
+      warning("Rounding R-square to fewer than two significant digits! Likely information loss!")
+    }
+    rr.char <- format(rr, digits = rr.digits)
+    adj.rr.char <- format(adj.rr, digits = rr.digits)
+    AIC.char <- sprintf("%.4g", AIC)
+    BIC.char <- sprintf("%.4g", BIC)
     if (output.type == "expression") {
-      lhs <- "italic(y)~`=`~"
-    } else if (output.type %in% c("latex", "tex", "tikz", "text")) {
-      lhs <- "y = "
+      z <- tibble::tibble(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
+                                        rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
+                                        adj.rr.label = paste("italic(R)[adj]^2",
+                                                             adj.rr.char, sep = "~`=`~"),
+                                        AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
+                                        BIC.label = paste("BIC", BIC.char, sep = "~`=`~"))
+    } else if (output.type %in% c("latex", "tex", "text")) {
+      z <-tibble::tibble(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
+                                        rr.label = paste("R^2", rr.char, sep = " = "),
+                                        adj.rr.label = paste("R_{adj}^2",
+                                                             adj.rr.char, sep = " = "),
+                                        AIC.label = paste("AIC", AIC.char, sep = " = "),
+                                        BIC.label = paste("BIC", BIC.char, sep = " = "))
+    } else if (!output.type %in% c("numeric")) {
+      warning("Unknown 'output.type' argument: ", output.type)
+    }
+  }
+
+  if (npc.used) {
+    margin.npc <- 0.05
+  } else {
+    # margin set by scale
+    margin.npc <- 0
+  }
+  if (is.character(label.x)) {
+    label.x <- compute_npcx(x = label.x, group = group.idx, h.step = hstep, margin.npc = margin.npc)
+    if (!npc.used) {
+      x.expanse <- abs(diff(range(data$x)))
+      x.min <- min(data$x)
+      label.x <- label.x * x.expanse + x.min
+    }
+  }
+  if (is.character(label.y)) {
+    label.y <- compute_npcy(y = label.y, group = group.idx, v.step = vstep, margin.npc = margin.npc)
+    if (!npc.used) {
+      y.expanse <- abs(diff(range(data$y)))
+      y.min <- min(data$y)
+      label.y <- label.y * y.expanse + y.min
     }
-  }
-  if (eq.with.lhs) {
-    eq.char <- paste(lhs, eq.char, sep = "")
-  }
-  rr.char <- format(rr, digits = rr.digits)
-  adj.rr.char <- format(adj.rr, digits = rr.digits)
-  AIC.char <- sprintf("%.4g", AIC)
-  BIC.char <- sprintf("%.4g", BIC)
-  if (output.type == "expression") {
-    z <- data.frame(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
-                    rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
-                    adj.rr.label = paste("italic(R)[adj]^2",
-                                         adj.rr.char, sep = "~`=`~"),
-                    AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
-                    BIC.label = paste("BIC", BIC.char, sep = "~`=`~"))
-  } else if (output.type %in% c("latex", "tex", "text")) {
-    z <- data.frame(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
-                    rr.label = paste("R^2", rr.char, sep = " = "),
-                    adj.rr.label = paste("R_{adj}^2",
-                                         adj.rr.char, sep = " = "),
-                    AIC.label = paste("AIC", AIC.char, sep = " = "),
-                    BIC.label = paste("BIC", BIC.char, sep = " = "))
   }
 
   if (npc.used) {
-    label.x <- compute_npcx(x = label.x, group = group.idx, h.step = 0)
-    label.y <- compute_npcy(y = label.y, group = group.idx, v.step = 0.07)
     z$npcx <- label.x
     z$x <- NA_real_
     z$npcy <- label.y
